traitsui\.tests\.test\_splitter\_prefs\_restored module
=======================================================

.. automodule:: traitsui.tests.test_splitter_prefs_restored
    :members:
    :undoc-members:
    :show-inheritance:
